# Changelog for picu

## 1.6 (2025-07-31)
### New features
- Support of Unicode up to 16.0.0 (ICU up to release 76)

## 1.5 (2024-09-08)
### New features
- Support of Unicode up to 15.0.1 (ICU up to release 74)

## 1.4 (2023-08-04)
### New features
- Add a method to check if a codepoint script is rtl

## 1.3 (2022-10-26)
### New features
- Fix deprecated module import
- Support of Unicode up to 14.0.0 (ICU up to release 71).

## 1.2 (2021-04-27)
### New features
- Wrap new ICU methods

## 1.1 (2020-12-04)
### New features
- Add more debug information in IDNA exceptions

## 1.0 (2018-09-06)
### New features
- Support of Python 3. Compatibility with python2 is preserved for this release.
- Support of Unicode up to 10.0.0 (ICU up to release 60).
